=====================
Savanna Testing Infra
=====================

This README file attempts to provide current and prospective contributors with
everything they need to know in order to start creating unit tests for Savanna.
